@@ -23,7 +23,7 @@ from hspylib.core.enums.exit_code import ExitCode
 from hspylib.core.exception.exceptions import WidgetExecutionError, WidgetNotFoundError
 from hspylib.core.metaclass.singleton import Singleton
 from hspylib.core.tools.commons import get_path
-from hspylib.core.tools.preconditions import check_state
+from hspylib.core.preconditions import check_state
 from hspylib.core.tools.text_tools import camelcase
 from hspylib.modules.cli.application.application import Application
 from hspylib.modules.cli.tui.extra.mdashboard.dashboard_item import DashboardItem
